/*
 * tam640_tables.h - sensor mode tables for tam640 HDR sensor.
 *
 * Copyright (c) 2015-2019, NVIDIA CORPORATION, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU General Public License,
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __TAM640_I2C_TABLES__
#define __TAM640_I2C_TABLES__

#define TAM640_TABLE_WAIT_MS    0
#define TAM640_TABLE_END    1

#define tam640_reg struct reg_8

static tam640_reg tam640_start_stream[] = {
    {0x0100, 0x01},
    {TAM640_TABLE_WAIT_MS, 3},
    {TAM640_TABLE_END, 0x00}
};

static tam640_reg tam640_stop_stream[] = {
    {0x0100, 0x00},
    {TAM640_TABLE_END, 0x00}
};

static tam640_reg tam640_mode_common[] = {
    {TAM640_TABLE_WAIT_MS, 10},
    /* software reset */
    {0x0103, 0x01},
    /* sensor config */
    {0x0114, 0x01}, /* D-Phy, 2-lane */
    {0x0128, 0x00},
    {0x012A, 0x18}, /* 24 MHz INCK */
    {0x012B, 0x00},
    /* access code - vendor addr. ranges */
    {0x30EB, 0x05},
    {0x30EB, 0x0C},
    {0x300A, 0xFF},
    {0x300B, 0xFF},
    {0x30EB, 0x05},
    {0x30EB, 0x09},
    /* cis tuning */
    {0x455E, 0x00},
    {0x471E, 0x4B},
    {0x4767, 0x0F},
    {0x4750, 0x14},
    {0x4540, 0x00},
    {0x47B4, 0x14},
    {0x4713, 0x30},
    {0x478B, 0x10},
    {0x478F, 0x10},
    {0x4793, 0x10},
    {0x4797, 0x0E},
    {0x479B, 0x0E},
    {TAM640_TABLE_END, 0x00}
};

static tam640_reg tam640_mode_640x480_30fps[] = {
    /* format settings */
    {0x0157, 0x00}, /* ANALOG_GAIN_GLOBAL[7:0] */
    {0x015A, 0x09}, /* COARSE_INTEG_TIME[15:8] */
    {0x015B, 0xbd}, /* COARSE_INTEG_TIME[7:0] */
    {0x0160, 0x01}, /* FRM_LENGTH[15:8] */
    {0x0161, 0xE0}, /* FRM_LENGTH[7:0] */
    {0x0162, 0x02}, /* LINE_LENGTH[15:8] */
    {0x0163, 0x86}, /* LINE_LENGTH[7:0] */
    {0x0164, 0x00},
    {0x0165, 0x08},
    {0x0166, 0x02},
    {0x0167, 0x87},
    {0x0168, 0x00},
    {0x0169, 0x00},
    {0x016A, 0x01},
    {0x016B, 0xE0},
    {0x016C, 0x02},
    {0x016D, 0x80},
    {0x016E, 0x01},
    {0x016F, 0xE0},
    {0x0170, 0x01},
    {0x0171, 0x01},
    {0x0174, 0x00},
    {0x0175, 0x00},
    {0x018C, 0x0A},
    {0x018D, 0x0A},
    {TAM640_TABLE_END, 0x00}
};

enum {
    TAM640_MODE_640x480_30FPS,

    TAM640_MODE_COMMON,
    TAM640_START_STREAM,
    TAM640_STOP_STREAM,
};

static tam640_reg *mode_table[] = {
    [TAM640_MODE_640x480_30FPS] = tam640_mode_640x480_30fps,

    [TAM640_MODE_COMMON]  = tam640_mode_common,
    [TAM640_START_STREAM]  = tam640_start_stream,
    [TAM640_STOP_STREAM]  = tam640_stop_stream,
};

static const int tam640_30fps[] = {
    30,
};

/*
 * WARNING: frmfmt ordering need to match mode definition in
 * device tree!
 */
static const struct camera_common_frmfmt tam640_frmfmt[] = {
    {{640, 480},    tam640_30fps, 1, 0, TAM640_MODE_640x480_30FPS},
};

#endif /* __TAM640_I2C_TABLES__ */
